angular.module('starter.controllers', [])

.controller('EventCtrl', function($scope, $ionicModal, $timeout, $ionicHistory, $state) {
    //再読み込み時の処理
    document.addEventListener("resume", function() {
        $state.go($state.current, {}, {
            reload: true
        });
    }, false);
    //Setting
    document.addEventListener("deviceready", onDeviceReadyStart, false);

    function onDeviceReadyStart() {
            $scope.db = window.sqlitePlugin.openDatabase({
                name: "howmanydays.db"
            });
            $scope.db.transaction(function(tx) {
                tx.executeSql('CREATE TABLE IF NOT EXISTS archive (ar_id integer primary key autoincrement, ar_date, ar_title, ar_tag)');
            });
            navigator.globalization.getPreferredLanguage(
                function(language) {
                    window.localStorage.setItem('language', language.value);
                },
                function() {
                    window.localStorage.setItem('language', "en");
                }
            );
            $timeout(function() {
                if (window.localStorage.getItem('language') === 'ja-JP') {
                    $scope.laguage_datemode = 'ja-JP';
                    $scope.language_daysuntil = 'あと何日';
                    $scope.language_dayssince = 'あれから何日';
                    $scope.language_days = '日';
                    $scope.language_weekday = ["日曜日", "月曜日", "火曜日", "水曜日", "木曜日", "金曜日", "土曜日"];
                    $scope.language_tags = 'タグ';
                    $scope.language_tag_empty = '未入力';
                    $scope.language_title = 'タイトル';
                    $scope.language_event = 'イベント';
                    $scope.language_date = '日付';
                    $scope.language_tag = 'タグ';
                    $scope.language_new = '新規作成';
                    $scope.language_edit = '変更';
                    $scope.language_back = '戻る';
                    $scope.language_close = '閉じる';
                    $scope.language_save = '保存';
                    $scope.language_edit_link = '編集';
                } else {
                    $scope.laguage_datemode = 'en-US';
                    $scope.language_daysuntil = 'Days Until';
                    $scope.language_dayssince = 'Days Since';
                    $scope.language_days = 'Days';
                    $scope.language_weekday = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"];
                    $scope.language_tags = 'Tags';
                    $scope.language_title = 'Title';
                    $scope.language_date = 'Date';
                    $scope.language_event = 'Event';
                    $scope.language_tag = 'Tag';
                    $scope.language_tag_empty = 'empty';
                    $scope.language_new = 'New Event';
                    $scope.language_edit = 'Edit Event';
                    $scope.language_back = 'Back';
                    $scope.language_close = 'Close';
                    $scope.language_save = 'Save';
                    $scope.language_edit_link = 'Edit';
                }
            });
        }
        //modal
    $ionicModal.fromTemplateUrl('templates/new-event.html', {
        scope: $scope
    }).then(function(modal) {
        $scope.modal = modal;
    });
    $ionicModal.fromTemplateUrl('templates/edit-event.html', {
        scope: $scope
    }).then(function(modal_edit) {
        $scope.modal_edit = modal_edit;
    });
    $scope.closeNewEventForm = function() {
        $scope.modal.hide();
    };
    $scope.closeEditEventForm = function() {
        $scope.modal_edit.hide();
    };
    //Error Alert
    $scope.onFail = function(message) {
        navigator.notification.alert(
            message,
            null,
            'Alert',
            'OK'
        );
    };
    //DB error
    $scope.dbErrorAlert = function(error) {
        navigator.notification.alert(
            error.message,
            null,
            'Alert',
            'OK'
        );
    };
    //Replace 00000000 => 0000/00/00
    $scope.getSlashDate = function(str) {
        var y = str.substr(0, 4);
        var m = str.substr(4, 2);
        var d = str.substr(6, 2);
        return y + "/" + m + "/" + d;
    };
    //Count Days
    $scope.getCountDays = function(event_date) {
        var m = new Date();
        var x = (event_date - m) / 1000 / 60 / 60 / 24 + 1;
        x = Math.floor(x);
        return x;
    };
    //Today 00000000
    $scope.getTodayInit = function() {
        var today_date = new Date();
        var y = String(today_date.getFullYear());
        var m = String(today_date.getMonth() + 1);
        var d = String(today_date.getDate());
        if (m < 10) {
            m = "0" + m;
        }
        if (d < 10) {
            d = "0" + d;
        }
        return y + m + d;
    };
    //Date Init
    $scope.getDateInit = function(event_date) {
        var y = String(event_date.getFullYear());
        var m = String(event_date.getMonth() + 1);
        var d = String(event_date.getDate());
        if (m < 10) {
            m = "0" + m;
        }
        if (d < 10) {
            d = "0" + d;
        }
        return y + m + d;
    };
    //Replace 00000000 => 0000-00-00
    $scope.changeForInputDate = function(str) {
        var y = str.substr(0, 4);
        var m = str.substr(4, 2);
        var d = str.substr(6, 2);
        return y + "-" + m + "-" + d;
    };
    //Replace 0000-00-00 => 00000000
    $scope.changeForDbDate = function(input_date) {
        var event_date = new Date(input_date);
        var y = String(event_date.getFullYear());
        var m = String(event_date.getMonth() + 1);
        var d = String(event_date.getDate());
        if (m < 10) {
            m = "0" + m;
        }
        if (d < 10) {
            d = "0" + d;
        }
        return y + m + d;
    };
    $scope.getLanguageDateForList = function(event_date) {
        if (window.localStorage.getItem('language') === 'ja-JP') {
            return $scope.getSlashDate($scope.getDateInit(event_date)) + ' ' + $scope.language_weekday[event_date.getDay()];
        } else {
            return event_date.toLocaleDateString();
        }
    };
    $scope.getLanguageDayAndDate = function(event_date) {
        if (window.localStorage.getItem('language') === 'ja-JP') {
            return $scope.getSlashDate($scope.getDateInit(event_date)) + ' ' + $scope.language_weekday[event_date.getDay()];
        } else {
            return event_date.toLocaleDateString();
        }
    };
    //Share
    $scope.shareMessage = function(count_days, event_title) {
        var event_until_or_since;
        if (window.localStorage.getItem('language') === 'ja-JP') {
            event_until_or_since = count_days > 0 ? 'まであと' : ' あれから';
            $scope.share_message = event_title + event_until_or_since + count_days + '日';
        } else {
            event_until_or_since = count_days > 0 ? $scope.language_daysuntil : $scope.language_dayssince;
            $scope.share_message = count_days + ' ' + event_until_or_since + ' ' + event_title;
        }
        window.plugins.socialsharing.share($scope.share_message);
    };
    //state action
    $scope.goBack = function() {
        $ionicHistory.goBack();
    };
    $scope.goUntil = function() {
        $state.go('tab.until');
    };
    $scope.goSince = function() {
        $state.go('tab.since');
    };
    $scope.goTags = function() {
        $state.go('tab.tags');
    };
    $scope.moveIndexHtml = function() {
        window.location.href = "index.html";
    };
    //New
    $scope.openNewEventForm = function() {
        $scope.modal.show();
        $scope.new_event = {};
        var event_date = new Date();
        $scope.new_datepicker = $scope.getLanguageDayAndDate(event_date);
        $scope.new_event.date = $scope.getTodayInit();
    };
    $scope.getNewDatePicker = function() {
        var options = {
            date: new Date($scope.getSlashDate($scope.new_event.date)),
            mode: 'date'
        };
        datePicker.show(options, function(date) {
            if (date) {
                $timeout(function() {
                    $scope.new_datepicker = $scope.getLanguageDayAndDate(date);
                    $scope.new_event.date = $scope.changeForDbDate(date);
                }, 100);
            }
        });
    };
    $scope.submitNewEvent = function() {
        if (!$scope.new_event.title) {
            navigator.notification.alert(
                'Please enter a title first',
                null,
                'Alert',
                'OK'
            );
            return false;
        }
        if (!$scope.new_event.date) {
            navigator.notification.alert(
                'Please select event date',
                null,
                'Alert',
                'OK'
            );
            return false;
        }
        if (!$scope.new_event.tag) {
            $scope.new_event.tag = '';
        }
        $scope.db.transaction(
            function(tx) {
                tx.executeSql("insert into archive (ar_date, ar_title, ar_tag) values (?, ?, ?)", [$scope.new_event.date, $scope.new_event.title, $scope.new_event.tag],
                    function(tx, rs) {
                        if ($scope.new_event.filepath) {
                            $scope.photo_id = rs.insertId;
                        }
                    }
                );
            },
            function(error) {
                $scope.dbErrorAlert(error);
            },
            function() {
                $timeout(function() {
                    $scope.moveIndexHtml();
                }, 100);
            }
        );
    };
    //Edit
    $scope.openEditEventForm = function(event_id) {
        $scope.modal_edit.show();
        $scope.edit_event = {};
        document.addEventListener("deviceready", onDeviceReady, false);

        function onDeviceReady() {
            $scope.event_id = event_id;
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select * from archive where ar_id = ?", [event_id],
                        function(tx, rs) {
                            var row = rs.rows.item(0);
                            $scope.edit_event.title = row.ar_title;
                            $scope.edit_datepicker = $scope.getLanguageDayAndDate(new Date($scope.getSlashDate(row.ar_date)));
                            $scope.edit_event.date = row.ar_date;
                            $scope.edit_event.tag = row.ar_tag;
                        }
                    );
                },
                function(error) {
                    $scope.dbErrorAlert(error);
                },
                function() {}
            );
        }
    };
    $scope.getEditDatePicker = function() {
        var options = {
            date: new Date($scope.getSlashDate($scope.edit_event.date)),
            mode: 'date'
        };
        datePicker.show(options, function(date) {
            if (date) {
                $timeout(function() {
                    $scope.edit_datepicker = $scope.getLanguageDayAndDate(date);
                    $scope.edit_event.date = $scope.changeForDbDate(date);
                }, 100);
            }
        });
    };

    $scope.submitEditEvent = function(event_id) {
        if (!$scope.edit_event.title) {
            navigator.notification.alert(
                'Please enter a title first',
                null,
                'Alert',
                'OK'
            );
            return false;
        }
        if (!$scope.edit_event.date) {
            navigator.notification.alert(
                'Please select event date',
                null,
                'Alert',
                'OK'
            );
            return false;
        }
        if (!$scope.edit_event.tag) {
            $scope.edit_event.tag = '';
        }
        document.addEventListener("deviceready", onDeviceReady, false);

        function onDeviceReady() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("update archive set ar_date = ?, ar_title = ?, ar_tag = ? where ar_id = ?", [$scope.edit_event.date, $scope.edit_event.title, $scope.edit_event.tag, event_id]);
                },
                function(error) {
                    $scope.dbErrorAlert(error);
                },
                function() {
                    $timeout(function() {
                        $scope.moveIndexHtml();
                    }, 100);
                }
            );
        }
    };

    //Delete
    $scope.deleteEvent = function(event_id) {
        navigator.notification.confirm(
            'Are you sure you want to delete this event?',
            onConfirm,
            'Delete', ['No', 'Yes']
        );

        function onConfirm(buttonIndex) {
            if (buttonIndex == 2) {
                $scope.db.transaction(
                    function(tx) {
                        tx.executeSql("delete from archive where ar_id = ?", [event_id]);
                    },
                    function(error) {
                        $scope.dbErrorAlert(error);
                    },
                    function() {
                        $scope.moveIndexHtml();
                    }
                );
            } else {
            }
        }
    };
    //Swipe Action
    $scope.previousUntilEvent = function(event_id, event_date) {
        document.addEventListener("deviceready", onDeviceReady, false);

        function onDeviceReady() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select ar_id from archive where ar_id < ? AND ar_date = ? order by ar_id desc limit 1", [event_id, event_date],
                        function(tx, rs) {
                            var row = rs.rows.item(0);
                            $scope.next_id = row.ar_id;
                        }
                    );
                },
                function(error) {
                    previousUntilSortByDate();
                },
                function() {
                    $state.go('tab.until-event', {
                        eventId: $scope.next_id
                    });
                }
            );
        }

        function previousUntilSortByDate() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select ar_id from archive where ar_id != ? AND ar_date < ? AND ar_date >= ? order by ar_date desc limit 1", [event_id, event_date, $scope.getTodayInit()],
                        function(tx, rs) {
                            var row = rs.rows.item(0);
                            $scope.next_id = row.ar_id;
                        }
                    );
                },
                function(error) {},
                function() {
                    $state.go('tab.until-event', {
                        eventId: $scope.next_id
                    });
                }
            );
        }
    };
    $scope.nextUntilEvent = function(event_id, event_date) {
        document.addEventListener("deviceready", onDeviceReady, false);

        function onDeviceReady() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select ar_id from archive where ar_id > ? AND ar_date = ? order by ar_id asc limit 1", [event_id, event_date],
                        function(tx, rs) {
                            var row = rs.rows.item(0);
                            $scope.next_id = row.ar_id;
                        }
                    );
                },
                function(error) {
                    nextUntilSortByDate();
                },
                function() {
                    $state.go('tab.until-event', {
                        eventId: $scope.next_id
                    });
                }
            );
        }

        function nextUntilSortByDate() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select ar_id from archive where ar_id != ? AND ar_date > ? order by ar_date asc limit 1", [event_id, event_date],
                        function(tx, rs) {
                            var row = rs.rows.item(0);
                            $scope.next_id = row.ar_id;
                        }
                    );
                },
                function(error) {},
                function() {
                    $state.go('tab.until-event', {
                        eventId: $scope.next_id
                    });
                }
            );
        }
    };
    $scope.previousSinceEvent = function(event_id, event_date) {
        document.addEventListener("deviceready", onDeviceReady, false);

        function onDeviceReady() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select ar_id from archive where ar_id < ? AND ar_date = ? order by ar_id desc limit 1", [event_id, event_date],
                        function(tx, rs) {
                            var row = rs.rows.item(0);
                            $scope.next_id = row.ar_id;
                        }
                    );
                },
                function(error) {
                    previousSinceSortByDate();
                },
                function() {
                    $state.go('tab.since-event', {
                        eventId: $scope.next_id
                    });
                }
            );
        }

        function previousSinceSortByDate() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select ar_id from archive where ar_id != ? AND ar_date > ? AND ar_date <= ? order by ar_date asc limit 1", [event_id, event_date, $scope.getTodayInit()],
                        function(tx, rs) {
                            var row = rs.rows.item(0);
                            $scope.next_id = row.ar_id;
                        }
                    );
                },
                function(error) {},
                function() {
                    $state.go('tab.since-event', {
                        eventId: $scope.next_id
                    });
                }
            );
        }
    };
    $scope.nextSinceEvent = function(event_id, event_date) {
        document.addEventListener("deviceready", onDeviceReady, false);

        function onDeviceReady() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select ar_id from archive where ar_id > ? AND ar_date = ? order by ar_id asc limit 1", [event_id, event_date],
                        function(tx, rs) {
                            var row = rs.rows.item(0);
                            $scope.next_id = row.ar_id;
                        }
                    );
                },
                function(error) {
                    nextSinceSortByDate();
                },
                function() {
                    $state.go('tab.since-event', {
                        eventId: $scope.next_id
                    });
                }
            );
        }

        function nextSinceSortByDate() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select ar_id from archive where ar_id != ? AND ar_date < ? order by ar_date desc limit 1", [event_id, event_date],
                        function(tx, rs) {
                            var row = rs.rows.item(0);
                            $scope.next_id = row.ar_id;
                        }
                    );
                },
                function(error) {},
                function() {
                    $state.go('tab.since-event', {
                        eventId: $scope.next_id
                    });
                }
            );
        }
    };
    $scope.previousTagEvent = function(event_id, event_date, event_tag) {
        var sql_where = 'ar_date < ? AND ar_date >= ?';
        var sql_orderby = 'ar_date desc';
        if (event_date <= $scope.getTodayInit()) {
            sql_where = 'ar_date > ? AND ar_date <= ?';
            sql_orderby = 'ar_date asc';
        }
        document.addEventListener("deviceready", onDeviceReady, false);

        function onDeviceReady() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select ar_id from archive where ar_tag = ? AND  ar_id < ? AND ar_date = ? order by ar_id desc limit 1", [event_tag, event_id, event_date],
                        function(tx, rs) {
                            var row = rs.rows.item(0);
                            $scope.next_id = row.ar_id;
                        }
                    );
                },
                function(error) {
                    previousTagSortByDate();
                },
                function() {
                    $state.go('tab.tag-event', {
                        eventId: $scope.next_id
                    });
                }
            );
        }

        function previousTagSortByDate() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select ar_id from archive where ar_tag = ? AND ar_id != ? AND " + sql_where + " order by " + sql_orderby + " limit 1", [event_tag, event_id, event_date, $scope.getTodayInit()],
                        function(tx, rs) {
                            var row = rs.rows.item(0);
                            $scope.next_id = row.ar_id;
                        }
                    );
                },
                function(error) {},
                function() {
                    $state.go('tab.tag-event', {
                        eventId: $scope.next_id
                    });
                }
            );
        }
    };
    $scope.nextTagEvent = function(event_id, event_date, event_tag) {
        var sql_where = 'ar_date > ?';
        var sql_orderby = 'ar_date asc';
        if (event_date <= $scope.getTodayInit()) {
            sql_where = 'ar_date < ?';
            sql_orderby = 'ar_date desc';
        }
        document.addEventListener("deviceready", onDeviceReady, false);

        function onDeviceReady() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select ar_id from archive where ar_tag = ? AND  ar_id > ? AND ar_date = ? order by ar_id asc limit 1", [event_tag, event_id, event_date],
                        function(tx, rs) {
                            var row = rs.rows.item(0);
                            $scope.next_id = row.ar_id;
                        }
                    );
                },
                function(error) {
                    nextTagSortByDate();
                },
                function() {
                    $state.go('tab.tag-event', {
                        eventId: $scope.next_id
                    });
                }
            );
        }

        function nextTagSortByDate() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select ar_id from archive where ar_tag = ? AND ar_id != ? AND " + sql_where + " order by " + sql_orderby + " limit 1", [event_tag, event_id, event_date],
                        function(tx, rs) {
                            var row = rs.rows.item(0);
                            $scope.next_id = row.ar_id;
                        }
                    );
                },
                function(error) {},
                function() {
                    $state.go('tab.tag-event', {
                        eventId: $scope.next_id
                    });
                }
            );
        }
    };
})

.controller('UntilCtrl', function($scope, $timeout) {
    document.addEventListener("deviceready", onDeviceReady, false);

    function onDeviceReady() {
        $scope.db.transaction(
            function(tx) {
                tx.executeSql("select * from archive where ar_date >= ? order by ar_date asc", [$scope.getTodayInit()],
                    function(tx, rs) {
                        var rows = [];
                        var img;
                        for (var i = 0; i < rs.rows.length; i++) {
                            var row = rs.rows.item(i);
                            rows.push({
                                id: row.ar_id,
                                title: row.ar_title,
                                date: $scope.getLanguageDateForList(new Date($scope.getSlashDate(row.ar_date))),
                                count_days: $scope.getCountDays(new Date($scope.getSlashDate(row.ar_date)))
                            });
                        }
                        $timeout(function() {
                            $scope.rows = rows;
                        });
                    }
                );
            },
            function(error) {
                $scope.dbErrorAlert(error);
            },
            function() {}
        );
    }
})

.controller('UntilEventCtrl', function($scope, $stateParams, $timeout) {
    document.addEventListener("deviceready", onDeviceReady, false);

    function onDeviceReady() {
        $scope.db.transaction(
            function(tx) {
                tx.executeSql("select * from archive where ar_id = ?", [$stateParams.eventId],
                    function(tx, rs) {
                        $timeout(function() {
                            $scope.row = rs.rows.item(0);
                            $scope.date = $scope.getLanguageDayAndDate(new Date($scope.getSlashDate($scope.row.ar_date)));
                            $scope.count_days = $scope.getCountDays(new Date($scope.getSlashDate($scope.row.ar_date)));
                        });
                    }
                );
            },
            function(error) {
                $scope.dbErrorAlert(error);
            },
            function() {}
        );
    }
})

.controller('SinceCtrl', function($scope, $timeout) {
        document.addEventListener("deviceready", onDeviceReady, false);

        function onDeviceReady() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select * from archive where ar_date <= ? order by ar_date desc", [$scope.getTodayInit()],
                        function(tx, rs) {
                            var rows = [];
                            var img;
                            for (var i = 0; i < rs.rows.length; i++) {
                                var row = rs.rows.item(i);
                                rows.push({
                                    id: row.ar_id,
                                    title: row.ar_title,
                                    date: $scope.getLanguageDateForList(new Date($scope.getSlashDate(row.ar_date))),
                                    count_days: $scope.getCountDays(new Date($scope.getSlashDate(row.ar_date)))
                                });
                            }
                            $timeout(function() {
                                $scope.rows = rows;
                            });
                        }
                    );
                },
                function(error) {
                    $scope.dbErrorAlert(error);
                },
                function() {}
            );
        }
    })
    .controller('SinceEventCtrl', function($scope, $stateParams, $timeout) {
        document.addEventListener("deviceready", onDeviceReady, false);

        function onDeviceReady() {
            $scope.db.transaction(
                function(tx) {
                    tx.executeSql("select * from archive where ar_id = ?", [$stateParams.eventId],
                        function(tx, rs) {
                            $timeout(function() {
                                $scope.row = rs.rows.item(0);
                                $scope.date = $scope.getLanguageDayAndDate(new Date($scope.getSlashDate($scope.row.ar_date)));
                                $scope.count_days = $scope.getCountDays(new Date($scope.getSlashDate($scope.row.ar_date)));
                            });
                        }
                    );
                },
                function(error) {
                    $scope.dbErrorAlert(error);
                },
                function() {}
            );
        }
    })

.controller('TagsCtrl', function($scope, $timeout) {
    document.addEventListener("deviceready", onDeviceReadyTags, false);

    function onDeviceReadyTags() {
        $scope.db.transaction(
            function(tx) {
                tx.executeSql("select COUNT(*) AS tag_count, ar_tag from archive group by ar_tag order by tag_count desc", [],
                    function(tx, rs) {
                        var rows = [];
                        for (var i = 0; i < rs.rows.length; i++) {
                            var row = rs.rows.item(i);
                            if (!row.ar_tag) {
                                row.ar_tag = $scope.language_tag_empty;
                            }
                            rows.push({
                                tag: row.ar_tag,
                                tag_count: row.tag_count
                            });
                        }
                        $timeout(function() {
                            $scope.rows = rows;
                        });
                    }
                );
            },
            function(error) {
                $scope.dbErrorAlert(error);
            },
            function() {}
        );
    }
})

.controller('TagCtrl', function($scope, $stateParams, $timeout) {
    $scope.tag_name = $stateParams.tagName;
    var tag_name = $stateParams.tagName;
    if (tag_name === $scope.language_tag_empty) {
        tag_name = '';
    }
    document.addEventListener("deviceready", onDeviceReady, false);

    function onDeviceReady() {
        $scope.db.transaction(
            function(tx) {
                tx.executeSql("select * from archive where ar_tag = ? AND ar_date > ? order by ar_date asc", [tag_name, $scope.getTodayInit()],
                    function(tx, rs) {
                        var rows = [];
                        var img;
                        for (var i = 0; i < rs.rows.length; i++) {
                            var row = rs.rows.item(i);
                            rows.push({
                                id: row.ar_id,
                                title: row.ar_title,
                                date: $scope.getLanguageDateForList(new Date($scope.getSlashDate(row.ar_date))),
                                count_days: $scope.getCountDays(new Date($scope.getSlashDate(row.ar_date)))
                            });
                        }
                        $timeout(function() {
                            $scope.until_rows = rows;
                        });
                    }
                );
            },
            function(error) {
                $scope.dbErrorAlert(error);
            },
            function() {}
        );
        $scope.db.transaction(
            function(tx) {
                tx.executeSql("select * from archive where ar_tag = ? AND ar_date <= ?  order by ar_date desc", [tag_name, $scope.getTodayInit()],
                    function(tx, rs) {
                        var rows = [];
                        var img;
                        for (var i = 0; i < rs.rows.length; i++) {
                            var row = rs.rows.item(i);
                            rows.push({
                                id: row.ar_id,
                                title: row.ar_title,
                                date: $scope.getLanguageDateForList(new Date($scope.getSlashDate(row.ar_date))),
                                count_days: $scope.getCountDays(new Date($scope.getSlashDate(row.ar_date)))
                            });
                        }
                        $timeout(function() {
                            $scope.since_rows = rows;
                        });
                    }
                );
            },
            function(error) {
                $scope.dbErrorAlert(error);
            },
            function() {}
        );
    }
})

.controller('TagEventCtrl', function($scope, $stateParams, $timeout) {
    document.addEventListener("deviceready", onDeviceReady, false);

    function onDeviceReady() {
        $scope.db.transaction(
            function(tx) {
                tx.executeSql("select * from archive where ar_id = ?", [$stateParams.eventId],
                    function(tx, rs) {
                        $timeout(function() {
                            $scope.row = rs.rows.item(0);
                            if (!$scope.row.ar_tag) {
                                $scope.row.ar_tag = $scope.language_tag_empty;
                            }
                            $scope.date = $scope.getLanguageDayAndDate(new Date($scope.getSlashDate($scope.row.ar_date)));
                            $scope.count_days = $scope.getCountDays(new Date($scope.getSlashDate($scope.row.ar_date)));
                        });
                    }
                );
            },
            function(error) {
                $scope.dbErrorAlert(error);
            },
            function() {}
        );
    }
})

;
